# Generated by Django 4.2.7 on 2024-01-31 08:58

from django.db import migrations, models
import django.db.models.deletion


class Migration(migrations.Migration):

    dependencies = [
        ('uzbekistan', '0002_alter_region_name_oz_alter_region_name_ru_and_more'),
    ]

    operations = [
        migrations.CreateModel(
            name='Village',
            fields=[
                ('id', models.BigAutoField(auto_created=True, primary_key=True, serialize=False, verbose_name='ID')),
                ('name_uz', models.CharField(max_length=255)),
                ('name_oz', models.CharField(max_length=255)),
                ('name_ru', models.CharField(max_length=255)),
                ('district', models.ForeignKey(on_delete=django.db.models.deletion.CASCADE, to='uzbekistan.district')),
            ],
            options={
                'db_table': 'villages',
                'unique_together': {('name_uz', 'name_oz', 'name_ru', 'district')},
            },
        ),
    ]
