# Generated by Django 4.2.7 on 2024-01-25 03:18

from django.db import migrations, models


class Migration(migrations.Migration):
    dependencies = [
        ('uzbekistan', '0001_initial'),
    ]

    operations = [
        migrations.AlterField(
            model_name='region',
            name='name_oz',
            field=models.CharField(max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name='region',
            name='name_ru',
            field=models.CharField(max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name='region',
            name='name_uz',
            field=models.CharField(max_length=255, unique=True),
        ),
        migrations.AlterField(
            model_name='region',
            name='name_en',
            field=models.CharField(max_length=255, unique=True),
        ),
        migrations.AlterUniqueTogether(
            name='district',
            unique_together={('name_uz', 'name_oz', 'name_ru', 'region')},
        ),
    ]
