# Generated by Django 4.2.7 on 2024-01-31 09:25

from django.db import migrations, models


class Migration(migrations.Migration):

    dependencies = [
        ('uzbekistan', '0003_village'),
    ]

    operations = [
        migrations.AddField(
            model_name='district',
            name='name_en',
            field=models.CharField(blank=True, max_length=255, null=True),
        ),
    ]
